Index: distribution/osx-pl2303-intel64-make-pkg.sh
===================================================================
--- distribution/osx-pl2303-intel64-make-pkg.sh	(revision 0)
+++ distribution/osx-pl2303-intel64-make-pkg.sh	(revision 0)
@@ -0,0 +1,48 @@
+#!/bin/sh
+
+PRODUCT_NAME="osx-pl2303-intel64"
+ID="nl.bjaelectronics.driver.PL2303"
+VERSION="0.3.2"
+BUILD_DIR="${PWD}/build"
+RESOURCE_DIR="${PWD}"
+
+KEXT_FILENAME="${BUILD_DIR}/${PRODUCT_NAME}.kext"
+SUBARCH_FILENAME="${BUILD_DIR}/osx-pl2303.pkg"
+ARCHIVE_FILENAME="${BUILD_DIR}/${PRODUCT_NAME}.pkg"
+DISTRIB_FILENAME="${BUILD_DIR}/distribution.xml"
+
+# clean previous runs
+rm -rf "${ARCHIVE_FILENAME}" "${SUBARCH_FILENAME}" "${DISTRIB_FILENAME}"
+
+# create raw installation package
+sudo chown -R root:wheel "${KEXT_FILENAME}"
+sudo chmod -R go-w "${KEXT_FILENAME}"
+
+pkgbuild --component "${KEXT_FILENAME}" \
+    --identifier "${ID}" \
+    --version "${VERSION}" \
+    --install-location "/System/Library/Extensions/" \
+    "${SUBARCH_FILENAME}"
+
+# create full installation package
+cat > "${DISTRIB_FILENAME}" <<EOT
+<?xml version="1.0" encoding="utf-8"?>
+<installer-gui-script minSpecVersion="1">
+    <title>OS X Pl2303 USB to Serial driver v${VERSION} OS X 10.7 (32/64bits)</title>
+    <welcome file="welcome.rtf" />
+    <license file="license.rtf" />
+    <options customize="never" />
+    <choices-outline>
+        <line choice="install"/>
+    </choices-outline>
+    <choice id="install" visible="true" title="Install" description="Installation description goes here">
+        <pkg-ref id="nl.bjaelectronics.driver.PL2303">#osx-pl2303.pkg</pkg-ref>
+    </choice>
+</installer-gui-script>
+EOT
+
+productbuild \
+    --distribution "${DISTRIB_FILENAME}" \
+    --resources "${RESOURCE_DIR}" \
+    --package-path "${BUILD_DIR}" \
+    "${ARCHIVE_FILENAME}"
Index: osx_pl2303.h
===================================================================
--- osx_pl2303.h	(revision 41)
+++ osx_pl2303.h	(working copy)
@@ -412,8 +412,10 @@
     virtual	IOReturn	dequeueDataGated(UInt8 *buffer, UInt32 size, UInt32 *count, UInt32 min);	
 	
     // Power management routines
+#ifndef __x86_64__
     virtual unsigned long initialPowerStateForDomainState ( IOPMPowerFlags );
     virtual IOReturn    setPowerState(unsigned long powerStateOrdinal, IOService * whatDevice);
+#endif
 	
 	bool				setUpTransmit( void );
 	IOReturn			setSerialConfiguration( void );
Index: Info.plist
===================================================================
--- Info.plist	(revision 41)
+++ Info.plist	(working copy)
@@ -1,11 +1,11 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<!DOCTYPE plist PUBLIC "-//Apple Computer//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
+<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
 	<key>CFBundleDevelopmentRegion</key>
 	<string>English</string>
 	<key>CFBundleExecutable</key>
-	<string>osx-pl2303</string>
+	<string>${EXECUTABLE_NAME}</string>
 	<key>CFBundleIconFile</key>
 	<string></string>
 	<key>CFBundleIdentifier</key>
@@ -19,7 +19,7 @@
 	<key>CFBundleSignature</key>
 	<string>????</string>
 	<key>CFBundleVersion</key>
-	<string>1.0.0d1</string>
+	<string>0.3.2</string>
 	<key>IOKitPersonalities</key>
 	<dict>
 		<key>04bb_0a03</key>
@@ -621,12 +621,23 @@
 			<integer>24969</integer>
 		</dict>
 	</dict>
-	<key>OSBundleLibraries</key>
+	<key>OSBundleLibraries_x86_64</key>
 	<dict>
 		<key>com.apple.iokit.IOSerialFamily</key>
 		<string>1.0.4</string>
 		<key>com.apple.iokit.IOUSBFamily</key>
 		<string>1.8</string>
+		<key>com.apple.kpi.iokit</key>
+		<string>8.0.0</string>
+		<key>com.apple.kpi.libkern</key>
+		<string>8.0.0</string>
+	</dict>
+	<key>OSBundleLibraries_i386</key>
+	<dict>
+		<key>com.apple.iokit.IOSerialFamily</key>
+		<string>1.0.4</string>
+		<key>com.apple.iokit.IOUSBFamily</key>
+		<string>1.8</string>
 		<key>com.apple.kernel.iokit</key>
 		<string>6.9.9</string>
 		<key>com.apple.kernel.libkern</key>
@@ -634,5 +645,18 @@
 		<key>com.apple.kernel.mach</key>
 		<string>6.9.9</string>
 	</dict>
+	<key>OSBundleLibraries_ppc</key>
+	<dict>
+		<key>com.apple.iokit.IOSerialFamily</key>
+		<string>1.0.4</string>
+		<key>com.apple.iokit.IOUSBFamily</key>
+		<string>1.8</string>
+		<key>com.apple.kernel.iokit</key>
+		<string>6.9.9</string>
+		<key>com.apple.kernel.libkern</key>
+		<string>6.9.9</string>
+		<key>com.apple.kernel.mach</key>
+		<string>6.9.9</string>
+	</dict>
 </dict>
 </plist>
Index: osx-pl2303.xcodeproj/project.pbxproj
===================================================================
--- osx-pl2303.xcodeproj/project.pbxproj	(revision 41)
+++ osx-pl2303.xcodeproj/project.pbxproj	(working copy)
@@ -7,6 +7,10 @@
 	objects = {
 
 /* Begin PBXBuildFile section */
+		27CAF4AA17C7073A00A794C0 /* osx_pl2303.h in Headers */ = {isa = PBXBuildFile; fileRef = 1A224C3EFF42367911CA2CB7 /* osx_pl2303.h */; };
+		27CAF4AC17C7073A00A794C0 /* InfoPlist.strings in Resources */ = {isa = PBXBuildFile; fileRef = 089C167DFE841241C02AAC07 /* InfoPlist.strings */; };
+		27CAF4AD17C7073A00A794C0 /* COPYING in Resources */ = {isa = PBXBuildFile; fileRef = 906D8A5709AF0FBC00CAB1B1 /* COPYING */; };
+		27CAF4AF17C7073A00A794C0 /* osx_pl2303.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 1A224C3FFF42367911CA2CB7 /* osx_pl2303.cpp */; settings = {ATTRIBUTES = (); }; };
 		32D94FC60562CBF700B6AF17 /* osx_pl2303.h in Headers */ = {isa = PBXBuildFile; fileRef = 1A224C3EFF42367911CA2CB7 /* osx_pl2303.h */; };
 		32D94FC80562CBF700B6AF17 /* InfoPlist.strings in Resources */ = {isa = PBXBuildFile; fileRef = 089C167DFE841241C02AAC07 /* InfoPlist.strings */; };
 		32D94FCA0562CBF700B6AF17 /* osx_pl2303.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 1A224C3FFF42367911CA2CB7 /* osx_pl2303.cpp */; settings = {ATTRIBUTES = (); }; };
@@ -17,34 +21,27 @@
 		906D8A5809AF0FBC00CAB1B1 /* COPYING in Resources */ = {isa = PBXBuildFile; fileRef = 906D8A5709AF0FBC00CAB1B1 /* COPYING */; };
 /* End PBXBuildFile section */
 
-/* Begin PBXBuildStyle section */
-		06AA1265FFB2107B11CA28AA /* Debug */ = {
-			isa = PBXBuildStyle;
-			buildSettings = {
-			};
-			name = Debug;
-		};
-		06AA1266FFB2107B11CA28AA /* Release */ = {
-			isa = PBXBuildStyle;
-			buildSettings = {
-			};
-			name = Release;
-		};
-/* End PBXBuildStyle section */
-
 /* Begin PBXFileReference section */
 		089C167EFE841241C02AAC07 /* English */ = {isa = PBXFileReference; fileEncoding = 10; lastKnownFileType = text.plist.strings; name = English; path = English.lproj/InfoPlist.strings; sourceTree = "<group>"; };
 		1A224C3EFF42367911CA2CB7 /* osx_pl2303.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = osx_pl2303.h; sourceTree = "<group>"; };
 		1A224C3FFF42367911CA2CB7 /* osx_pl2303.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; path = osx_pl2303.cpp; sourceTree = "<group>"; };
-		32D94FCF0562CBF700B6AF17 /* Info.plist */ = {isa = PBXFileReference; lastKnownFileType = text.xml; path = Info.plist; sourceTree = "<group>"; };
+		27CAF4B617C7073A00A794C0 /* osx-pl2303-intel64.kext */ = {isa = PBXFileReference; explicitFileType = wrapper.cfbundle; includeInIndex = 0; path = "osx-pl2303-intel64.kext"; sourceTree = BUILT_PRODUCTS_DIR; };
+		32D94FCF0562CBF700B6AF17 /* Info.plist */ = {isa = PBXFileReference; lastKnownFileType = text.plist.xml; path = Info.plist; sourceTree = "<group>"; };
 		32D94FD00562CBF700B6AF17 /* osx-pl2303.kext */ = {isa = PBXFileReference; explicitFileType = wrapper.cfbundle; includeInIndex = 0; path = "osx-pl2303.kext"; sourceTree = BUILT_PRODUCTS_DIR; };
 		8DA8362C06AD9B9200E5AC22 /* Kernel.framework */ = {isa = PBXFileReference; lastKnownFileType = wrapper.framework; name = Kernel.framework; path = /System/Library/Frameworks/Kernel.framework; sourceTree = "<absolute>"; };
 		906D8A5709AF0FBC00CAB1B1 /* COPYING */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = text; path = COPYING; sourceTree = "<group>"; };
 		90FB12BF0A3AE7D200C1B579 /* release-osx-10.3.x.kext */ = {isa = PBXFileReference; explicitFileType = wrapper.cfbundle; includeInIndex = 0; path = "release-osx-10.3.x.kext"; sourceTree = BUILT_PRODUCTS_DIR; };
-		90FB12C00A3AE7D200C1B579 /* release-osx-10.3.x-Info.plist */ = {isa = PBXFileReference; lastKnownFileType = text.xml; path = "release-osx-10.3.x-Info.plist"; sourceTree = "<group>"; };
+		90FB12C00A3AE7D200C1B579 /* release-osx-10.3.x-Info.plist */ = {isa = PBXFileReference; lastKnownFileType = text.plist.xml; path = "release-osx-10.3.x-Info.plist"; sourceTree = "<group>"; };
 /* End PBXFileReference section */
 
 /* Begin PBXFrameworksBuildPhase section */
+		27CAF4B017C7073A00A794C0 /* Frameworks */ = {
+			isa = PBXFrameworksBuildPhase;
+			buildActionMask = 2147483647;
+			files = (
+			);
+			runOnlyForDeploymentPostprocessing = 0;
+		};
 		32D94FCB0562CBF700B6AF17 /* Frameworks */ = {
 			isa = PBXFrameworksBuildPhase;
 			buildActionMask = 2147483647;
@@ -90,6 +87,7 @@
 			children = (
 				32D94FD00562CBF700B6AF17 /* osx-pl2303.kext */,
 				90FB12BF0A3AE7D200C1B579 /* release-osx-10.3.x.kext */,
+				27CAF4B617C7073A00A794C0 /* osx-pl2303-intel64.kext */,
 			);
 			name = Products;
 			sourceTree = "<group>";
@@ -113,6 +111,14 @@
 /* End PBXGroup section */
 
 /* Begin PBXHeadersBuildPhase section */
+		27CAF4A917C7073A00A794C0 /* Headers */ = {
+			isa = PBXHeadersBuildPhase;
+			buildActionMask = 2147483647;
+			files = (
+				27CAF4AA17C7073A00A794C0 /* osx_pl2303.h in Headers */,
+			);
+			runOnlyForDeploymentPostprocessing = 0;
+		};
 		32D94FC50562CBF700B6AF17 /* Headers */ = {
 			isa = PBXHeadersBuildPhase;
 			buildActionMask = 2147483647;
@@ -132,6 +138,26 @@
 /* End PBXHeadersBuildPhase section */
 
 /* Begin PBXNativeTarget section */
+		27CAF4A817C7073A00A794C0 /* osx-pl2303-10.7-32/64bits */ = {
+			isa = PBXNativeTarget;
+			buildConfigurationList = 27CAF4B217C7073A00A794C0 /* Build configuration list for PBXNativeTarget "osx-pl2303-10.7-32/64bits" */;
+			buildPhases = (
+				27CAF4A917C7073A00A794C0 /* Headers */,
+				27CAF4AB17C7073A00A794C0 /* Resources */,
+				27CAF4AE17C7073A00A794C0 /* Sources */,
+				27CAF4B017C7073A00A794C0 /* Frameworks */,
+				27CAF4B117C7073A00A794C0 /* Rez */,
+			);
+			buildRules = (
+			);
+			dependencies = (
+			);
+			name = "osx-pl2303-10.7-32/64bits";
+			productInstallPath = "$(SYSTEM_LIBRARY_DIR)/Extensions";
+			productName = "osx-pl2303";
+			productReference = 27CAF4B617C7073A00A794C0 /* osx-pl2303-intel64.kext */;
+			productType = "com.apple.product-type.kernel-extension.iokit";
+		};
 		32D94FC30562CBF700B6AF17 /* osx-pl2303-10.4-universal */ = {
 			isa = PBXNativeTarget;
 			buildConfigurationList = 1DEB91D908733DB10010E9CD /* Build configuration list for PBXNativeTarget "osx-pl2303-10.4-universal" */;
@@ -144,8 +170,6 @@
 			);
 			buildRules = (
 			);
-			buildSettings = {
-			};
 			dependencies = (
 			);
 			name = "osx-pl2303-10.4-universal";
@@ -166,48 +190,11 @@
 			);
 			buildRules = (
 			);
-			buildSettings = {
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_MODEL_TUNING = G5;
-				INFOPLIST_FILE = "release-osx-10.3.x-Info.plist";
-				INSTALL_PATH = "$(SYSTEM_LIBRARY_DIR)/Extensions";
-				MODULE_NAME = com.yourcompany.driver.release_osx_10_3_x;
-				MODULE_VERSION = 1.0.0d1;
-				PREBINDING = NO;
-				PRODUCT_NAME = "release-osx-10.3.x";
-				WRAPPER_EXTENSION = kext;
-				ZERO_LINK = YES;
-			};
 			dependencies = (
 			);
 			name = "osx-pl2303-10.3.9";
 			productName = "release-osx-10.3.x";
 			productReference = 90FB12BF0A3AE7D200C1B579 /* release-osx-10.3.x.kext */;
-			productSettingsXML = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>
-<!DOCTYPE plist PUBLIC \"-//Apple Computer//DTD PLIST 1.0//EN\" \"http://www.apple.com/DTDs/PropertyList-1.0.dtd\">
-<plist version=\"1.0\">
-<dict>
-	<key>CFBundleDevelopmentRegion</key>
-	<string>English</string>
-	<key>CFBundleExecutable</key>
-	<string>${EXECUTABLE_NAME}</string>
-	<key>CFBundleIdentifier</key>
-	<string>com.yourcompany.driver.release-osx-10.3.x</string>
-	<key>CFBundleInfoDictionaryVersion</key>
-	<string>6.0</string>
-	<key>CFBundlePackageType</key>
-	<string>KEXT</string>
-	<key>CFBundleSignature</key>
-	<string>????</string>
-	<key>CFBundleVersion</key>
-	<string>1.0.0d1</string>
-	<key>IOKitPersonalities</key>
-	<dict/>
-	<key>OSBundleLibraries</key>
-	<dict/>
-</dict>
-</plist>
-";
 			productType = "com.apple.product-type.kernel-extension.iokit";
 		};
 /* End PBXNativeTarget section */
@@ -216,23 +203,33 @@
 		089C1669FE841209C02AAC07 /* Project object */ = {
 			isa = PBXProject;
 			buildConfigurationList = 1DEB91DD08733DB10010E9CD /* Build configuration list for PBXProject "osx-pl2303" */;
-			buildSettings = {
-			};
-			buildStyles = (
-				06AA1265FFB2107B11CA28AA /* Debug */,
-				06AA1266FFB2107B11CA28AA /* Release */,
+			compatibilityVersion = "Xcode 2.4";
+			developmentRegion = English;
+			hasScannedForEncodings = 1;
+			knownRegions = (
+				en,
 			);
-			hasScannedForEncodings = 1;
 			mainGroup = 089C166AFE841209C02AAC07 /* osx-pl2303 */;
 			projectDirPath = "";
+			projectRoot = "";
 			targets = (
 				32D94FC30562CBF700B6AF17 /* osx-pl2303-10.4-universal */,
 				90FB12BE0A3AE7D200C1B579 /* osx-pl2303-10.3.9 */,
+				27CAF4A817C7073A00A794C0 /* osx-pl2303-10.7-32/64bits */,
 			);
 		};
 /* End PBXProject section */
 
 /* Begin PBXResourcesBuildPhase section */
+		27CAF4AB17C7073A00A794C0 /* Resources */ = {
+			isa = PBXResourcesBuildPhase;
+			buildActionMask = 2147483647;
+			files = (
+				27CAF4AC17C7073A00A794C0 /* InfoPlist.strings in Resources */,
+				27CAF4AD17C7073A00A794C0 /* COPYING in Resources */,
+			);
+			runOnlyForDeploymentPostprocessing = 0;
+		};
 		32D94FC70562CBF700B6AF17 /* Resources */ = {
 			isa = PBXResourcesBuildPhase;
 			buildActionMask = 2147483647;
@@ -254,6 +251,13 @@
 /* End PBXResourcesBuildPhase section */
 
 /* Begin PBXRezBuildPhase section */
+		27CAF4B117C7073A00A794C0 /* Rez */ = {
+			isa = PBXRezBuildPhase;
+			buildActionMask = 2147483647;
+			files = (
+			);
+			runOnlyForDeploymentPostprocessing = 0;
+		};
 		32D94FCC0562CBF700B6AF17 /* Rez */ = {
 			isa = PBXRezBuildPhase;
 			buildActionMask = 2147483647;
@@ -271,6 +275,14 @@
 /* End PBXRezBuildPhase section */
 
 /* Begin PBXSourcesBuildPhase section */
+		27CAF4AE17C7073A00A794C0 /* Sources */ = {
+			isa = PBXSourcesBuildPhase;
+			buildActionMask = 2147483647;
+			files = (
+				27CAF4AF17C7073A00A794C0 /* osx_pl2303.cpp in Sources */,
+			);
+			runOnlyForDeploymentPostprocessing = 0;
+		};
 		32D94FC90562CBF700B6AF17 /* Sources */ = {
 			isa = PBXSourcesBuildPhase;
 			buildActionMask = 2147483647;
@@ -344,9 +356,7 @@
 			buildSettings = {
 				GCC_WARN_ABOUT_RETURN_TYPE = YES;
 				GCC_WARN_UNUSED_VARIABLE = YES;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
 				PREBINDING = NO;
-				SDKROOT = /Developer/SDKs/MacOSX10.4u.sdk;
 			};
 			name = Debug;
 		};
@@ -355,12 +365,130 @@
 			buildSettings = {
 				GCC_WARN_ABOUT_RETURN_TYPE = YES;
 				GCC_WARN_UNUSED_VARIABLE = YES;
 				MACOSX_DEPLOYMENT_TARGET = 10.4;
 				PREBINDING = NO;
 				SDKROOT = /Developer/SDKs/MacOSX10.4u.sdk;
 			};
 			name = "Release-10.4-universal";
 		};
+		27CAF4B317C7073A00A794C0 /* Debug */ = {
+			isa = XCBuildConfiguration;
+			buildSettings = {
+				COPY_PHASE_STRIP = NO;
+				CURRENT_PROJECT_VERSION = 1.0.0d1;
+				GCC_DYNAMIC_NO_PIC = NO;
+				GCC_ENABLE_FIX_AND_CONTINUE = YES;
+				GCC_MODEL_TUNING = G5;
+				GCC_OPTIMIZATION_LEVEL = 0;
+				INFOPLIST_FILE = Info.plist;
+				INSTALL_PATH = "$(SYSTEM_LIBRARY_DIR)/Extensions";
+				MODULE_NAME = com.yourcompany.driver.osx_pl2303;
+				MODULE_VERSION = 1.0.0d1;
+				PRODUCT_NAME = "osx-pl2303-intel64";
+				WRAPPER_EXTENSION = kext;
+				ZERO_LINK = YES;
+			};
+			name = Debug;
+		};
+		27CAF4B417C7073A00A794C0 /* Release-10.4-universal */ = {
+			isa = XCBuildConfiguration;
+			buildSettings = {
+				ARCHS = (
+					ppc,
+					i386,
+				);
+				CURRENT_PROJECT_VERSION = 1.0.0d1;
+				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
+				GCC_MODEL_TUNING = G5;
+				INFOPLIST_FILE = Info.plist;
+				INSTALL_PATH = "$(SYSTEM_LIBRARY_DIR)/Extensions";
+				MODULE_NAME = com.yourcompany.driver.osx_pl2303;
+				MODULE_VERSION = 1.0.0d1;
+				PRODUCT_NAME = "osx-pl2303-intel64";
+				WRAPPER_EXTENSION = kext;
+			};
+			name = "Release-10.4-universal";
+		};
+		27CAF4B517C7073A00A794C0 /* Release-10.3.9 */ = {
+			isa = XCBuildConfiguration;
+			buildSettings = {
+				ARCHS = (
+					ppc,
+					i386,
+				);
+				CURRENT_PROJECT_VERSION = 1.0.0d1;
+				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
+				GCC_MODEL_TUNING = G5;
+				INFOPLIST_FILE = Info.plist;
+				INSTALL_PATH = "$(SYSTEM_LIBRARY_DIR)/Extensions";
+				MODULE_NAME = com.yourcompany.driver.osx_pl2303;
+				MODULE_VERSION = 1.0.0d1;
+				PRODUCT_NAME = "osx-pl2303-intel64";
+				WRAPPER_EXTENSION = kext;
+			};
+			name = "Release-10.3.9";
+		};
+		27CAF4B817C7091300A794C0 /* Release-10.7-universal */ = {
+			isa = XCBuildConfiguration;
+			buildSettings = {
+				GCC_WARN_ABOUT_RETURN_TYPE = YES;
+				GCC_WARN_UNUSED_VARIABLE = YES;
+				PREBINDING = NO;
+				SDKROOT = macosx10.7;
+			};
+			name = "Release-10.7-universal";
+		};
+		27CAF4B917C7091300A794C0 /* Release-10.7-universal */ = {
+			isa = XCBuildConfiguration;
+			buildSettings = {
+				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
+				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
+				CURRENT_PROJECT_VERSION = 1.0.0d1;
+				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
+				GCC_MODEL_TUNING = G5;
+				INFOPLIST_FILE = Info.plist;
+				INSTALL_PATH = "$(SYSTEM_LIBRARY_DIR)/Extensions";
+				MODULE_NAME = com.yourcompany.driver.osx_pl2303;
+				MODULE_VERSION = 1.0.0d1;
+				PRODUCT_NAME = "osx-pl2303";
+				WRAPPER_EXTENSION = kext;
+			};
+			name = "Release-10.7-universal";
+		};
+		27CAF4BA17C7091300A794C0 /* Release-10.7-universal */ = {
+			isa = XCBuildConfiguration;
+			buildSettings = {
+				COPY_PHASE_STRIP = YES;
+				GCC_ENABLE_FIX_AND_CONTINUE = NO;
+				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
+				GCC_MODEL_TUNING = G5;
+				INFOPLIST_FILE = "release-osx-10.3.x-Info.plist";
+				INSTALL_PATH = "$(SYSTEM_LIBRARY_DIR)/Extensions";
+				MODULE_NAME = com.yourcompany.driver.release_osx_10_3_x;
+				MODULE_VERSION = 1.0.0d1;
+				PREBINDING = NO;
+				PRODUCT_NAME = "release-osx-10.3.x";
+				WRAPPER_EXTENSION = kext;
+				ZERO_LINK = NO;
+			};
+			name = "Release-10.7-universal";
+		};
+		27CAF4BB17C7091300A794C0 /* Release-10.7-universal */ = {
+			isa = XCBuildConfiguration;
+			buildSettings = {
+				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
+				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
+				CURRENT_PROJECT_VERSION = 1.0.0d1;
+				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
+				GCC_MODEL_TUNING = G5;
+				INFOPLIST_FILE = Info.plist;
+				INSTALL_PATH = "$(SYSTEM_LIBRARY_DIR)/Extensions";
+				MODULE_NAME = com.yourcompany.driver.osx_pl2303;
+				MODULE_VERSION = 1.0.0d1;
+				PRODUCT_NAME = "osx-pl2303-intel64";
+				WRAPPER_EXTENSION = kext;
+			};
+			name = "Release-10.7-universal";
+		};
 		90FB12C20A3AE7D300C1B579 /* Debug */ = {
 			isa = XCBuildConfiguration;
 			buildSettings = {
@@ -441,9 +569,8 @@
 			buildSettings = {
 				GCC_WARN_ABOUT_RETURN_TYPE = YES;
 				GCC_WARN_UNUSED_VARIABLE = YES;
 				MACOSX_DEPLOYMENT_TARGET = 10.3;
 				PREBINDING = NO;
-				SDKROOT = /Developer/SDKs/MacOSX10.4u.sdk;
+				SDKROOT = /Developer/SDKs/MacOSX10.3.9.sdk;
 			};
 			name = "Release-10.3.9";
 		};
@@ -455,30 +582,44 @@
 			buildConfigurations = (
 				1DEB91DA08733DB10010E9CD /* Debug */,
 				1DEB91DB08733DB10010E9CD /* Release-10.4-universal */,
+				27CAF4B917C7091300A794C0 /* Release-10.7-universal */,
 				90FB12C70A3AE90D00C1B579 /* Release-10.3.9 */,
 			);
 			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = "Release-10.4-universal";
+			defaultConfigurationName = "Release-10.7-universal";
 		};
 		1DEB91DD08733DB10010E9CD /* Build configuration list for PBXProject "osx-pl2303" */ = {
 			isa = XCConfigurationList;
 			buildConfigurations = (
 				1DEB91DE08733DB10010E9CD /* Debug */,
 				1DEB91DF08733DB10010E9CD /* Release-10.4-universal */,
+				27CAF4B817C7091300A794C0 /* Release-10.7-universal */,
 				90FB12C90A3AE90D00C1B579 /* Release-10.3.9 */,
 			);
 			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = "Release-10.4-universal";
+			defaultConfigurationName = "Release-10.7-universal";
 		};
+		27CAF4B217C7073A00A794C0 /* Build configuration list for PBXNativeTarget "osx-pl2303-10.7-32/64bits" */ = {
+			isa = XCConfigurationList;
+			buildConfigurations = (
+				27CAF4B317C7073A00A794C0 /* Debug */,
+				27CAF4B417C7073A00A794C0 /* Release-10.4-universal */,
+				27CAF4BB17C7091300A794C0 /* Release-10.7-universal */,
+				27CAF4B517C7073A00A794C0 /* Release-10.3.9 */,
+			);
+			defaultConfigurationIsVisible = 0;
+			defaultConfigurationName = "Release-10.7-universal";
+		};
 		90FB12C10A3AE7D300C1B579 /* Build configuration list for PBXNativeTarget "osx-pl2303-10.3.9" */ = {
 			isa = XCConfigurationList;
 			buildConfigurations = (
 				90FB12C20A3AE7D300C1B579 /* Debug */,
 				90FB12C30A3AE7D300C1B579 /* Release-10.4-universal */,
+				27CAF4BA17C7091300A794C0 /* Release-10.7-universal */,
 				90FB12C80A3AE90D00C1B579 /* Release-10.3.9 */,
 			);
 			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = "Release-10.4-universal";
+			defaultConfigurationName = "Release-10.7-universal";
 		};
 /* End XCConfigurationList section */
 	};
Index: osx_pl2303.cpp
===================================================================
--- osx_pl2303.cpp	(revision 41)
+++ osx_pl2303.cpp	(working copy)
@@ -80,6 +80,9 @@
 
 OSDefineMetaClassAndStructors(nl_bjaelectronics_driver_PL2303, IOSerialDriverSync)
 
+#ifdef __x86_64__
+#define KUNCUserNotificationDisplayNotice(args...)
+#endif
 
 /****************************************************************************************************/
 //
@@ -133,6 +136,7 @@
 bool nl_bjaelectronics_driver_PL2303::start(IOService *provider)
 {
     enum pl2303_type type = type_1;
+    OSNumber *	release;
 
     fTerminate = false;     // Make sure we don't think we're being terminated
     fPort = NULL;
@@ -211,7 +215,7 @@
 	
     fCommandGate->enable();	
 
-	OSNumber *	release = (OSNumber *) fpDevice->getProperty(kUSBDeviceReleaseNumber);
+	release = (OSNumber *) fpDevice->getProperty(kUSBDeviceReleaseNumber);
 
 	DEBUG_IOLog(1,"%s(%p)::start - Get device version: %p \n", getName(), this, release->unsigned16BitValue() );
 	
@@ -1815,7 +1819,7 @@
 {
     DEBUG_IOLog(4,"nl_bjaelectronics_driver_PL2303::setStateAction\n");
 
-    return ((nl_bjaelectronics_driver_PL2303 *)owner)->setStateGated((UInt32)arg0, (UInt32)arg1, (void *)arg2);
+    return ((nl_bjaelectronics_driver_PL2303 *)owner)->setStateGated((UInt32)(uintptr_t)arg0, (UInt32)(uintptr_t)arg1, (void *)arg2);
     
 }/* end setStateAction */
 
@@ -1907,7 +1911,7 @@
 {
     DEBUG_IOLog(4,"nl_bjaelectronics_driver_PL2303::watchStateAction\n");
 
-    return ((nl_bjaelectronics_driver_PL2303 *)owner)->watchStateGated((UInt32 *)arg0, (UInt32)arg1);
+    return ((nl_bjaelectronics_driver_PL2303 *)owner)->watchStateGated((UInt32 *)arg0, (UInt32)(uintptr_t)arg1);
     
 }/* end watchStateAction */
 
@@ -2005,7 +2009,7 @@
 {
 	DEBUG_IOLog(4,"nl_bjaelectronics_driver_PL2303::executeEventAction\n");
 
-	return ((nl_bjaelectronics_driver_PL2303 *)owner)->executeEventGated((UInt32)arg0, (UInt32)arg1, (void *)arg2);
+	return ((nl_bjaelectronics_driver_PL2303 *)owner)->executeEventGated((UInt32)(uintptr_t)arg0, (UInt32)(uintptr_t)arg1, (void *)arg2);
     
 }/* end executeEventAction */
 
@@ -2409,7 +2413,7 @@
 {
 	DEBUG_IOLog(4,"nl_bjaelectronics_driver_PL2303::requestEventAction\n");
 
-    return ((nl_bjaelectronics_driver_PL2303 *)owner)->requestEventGated((UInt32)arg0, (UInt32 *)arg1, (void *)arg2);
+    return ((nl_bjaelectronics_driver_PL2303 *)owner)->requestEventGated((UInt32)(uintptr_t)arg0, (UInt32 *)arg1, (void *)arg2);
     
 }/* end requestEventAction */
 
@@ -2720,7 +2724,7 @@
 
 IOReturn nl_bjaelectronics_driver_PL2303::enqueueDataAction(OSObject *owner, void *arg0, void *arg1, void *arg2, void *arg3)
 {
-    return ((nl_bjaelectronics_driver_PL2303 *)owner)->enqueueDataGated((UInt8 *)arg0, (UInt32)arg1, (UInt32 *)arg2, (bool)arg3);
+    return ((nl_bjaelectronics_driver_PL2303 *)owner)->enqueueDataGated((UInt8 *)arg0, (UInt32)(uintptr_t)arg1, (UInt32 *)arg2, (bool)arg3);
     
 }/* end enqueueDataAction */
 
@@ -2868,7 +2872,7 @@
 {
 	DEBUG_IOLog(4,"nl_bjaelectronics_driver_PL2303::dequeueDataAction\n");
 
-    return ((nl_bjaelectronics_driver_PL2303 *)owner)->dequeueDataGated((UInt8 *)arg0, (UInt32)arg1, (UInt32 *)arg2, (UInt32)arg3);
+    return ((nl_bjaelectronics_driver_PL2303 *)owner)->dequeueDataGated((UInt8 *)arg0, (UInt32)(uintptr_t)arg1, (UInt32 *)arg2, (UInt32)(uintptr_t)arg3);
     
 }/* end dequeueDataAction */
 
